import { graphql } from "@/gql";
import { VenueFragment, VenueIndexFragment } from "@/gql/graphql";
import { getClient } from "@/app/client";
import { VenueList } from "@/components/venues/VenueList";
import { PageHeader } from "@/components/general/PageHeader";
import { PageContent } from "@/components/general/PageContent";

const VenueIndexDefinition = graphql(`
  fragment VenueIndex on VenueIndex {
    ... on VenueIndex {
      title
      lead
      body {
        ...Blocks
      }
    }
  }
`);

const VenueFragmentDefinition = graphql(`
  fragment Venue on VenuePage {
    __typename
    id
    slug
    title
    images {
      ...Blocks
    }
    body {
      ...Blocks
    }
    featuredImage {
      ...Image
    }
    showAsBookable
    showInOverview
    floor
    preposition
    usedFor
    techSpecsUrl
    capabilityAudio
    capabilityAudioVideo
    capabilityBar
    capabilityLighting
    capacityLegal
    capacityStanding
    capacitySitting
  }
`);

export default async function Page() {
  const venueIndexQuery = graphql(`
    query venueIndex {
      index: venueIndex {
        ... on VenueIndex {
          ...VenueIndex
        }
      }
      venues: pages(contentType: "venues.VenuePage", limit: 100) {
        ... on VenuePage {
          ...Venue
        }
      }
    }
  `);
  const { data, error } = await getClient().query(venueIndexQuery, {});
  const index = (data?.index ?? []) as VenueIndexFragment;
  const venues = (data?.venues ?? []) as VenueFragment[];
  const visibleVenues = venues.filter((x) => x.showInOverview);

  return (
    <main className="site-main" id="main">
      <PageHeader heading={index.title} lead={index.lead} />
      <PageContent blocks={index.body} />
      <VenueList venues={venues} />
    </main>
  );
}
